
#ifndef VKBetaSpectrum_H
#define VKBetaSpectrum_H 1

#include "TF1.h"


class VKBetaSpectrum
{
  public:

    /*
     * Allowed beta spectrum
     * @param Z_daughter Charge of daughter nucleus (use negative value for positron emission)
     * @param A Nucleon numbers
     * @param endPointKinEnergy End-point kinetic energy
     * @param shapeFunc Shape function (x = total beta energy in MeV)
     */ 
    VKBetaSpectrum(int Z_daughter, int A, G4double endPointKinEnergy, TF1 * shapeFunc = nullptr);
    virtual ~VKBetaSpectrum();
    
    /*
     * Compute spectrum
     * @param x Kinetic energy in MeV
     * @param p Parameters (not used)
     */ 
    double Evaluate(double *x, double *par);

  private:
    double bremsstrahlungFactor(double W, double W0);
    
    TF1 * shapeFunc;
    double Z, A;
    double W0;
    double me;
    double alpha;
    double gamma;
    double R;
    double d1;
    double M;
};

#endif
