//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
#ifndef VKMagnet_H
#define VKMagnet_H 1

#include "G4PVPlacement.hh"
#include "G4Box.hh"
#include "G4Tubs.hh"
#include "G4Sphere.hh"
#include "G4Material.hh"
#include "G4LogicalVolume.hh"
#include "G4UnionSolid.hh"

#include "VKDetectorConstruction.hh"
#include "VKMaterials.hh"

class VKMagnet : public G4PVPlacement
{
  public:

    /*
     * Construct the main components of the Siegbahn-Slätis magnet: 
     * Copper coils, outer iron walls and inner brass surface.
     * @param pRot Orientation of magnet 
     * @param tlate Position of magnet
     * @param pMotherLogical Place magnet inside this volume
     * @param pMany Boolean operations
     * @param pCopyNo Copy number
     * @param pDetConstr Pointer to main detector constructor
     */
    VKMagnet(G4RotationMatrix *pRot,
             const G4ThreeVector &tlate,
             G4LogicalVolume *pMother_log,
             G4bool pMany,
             G4int pCopyNo,
             const VKDetectorConstruction* pDetConstr);
             
  private:

    void VisAttributes();
    void SetDefaults();
    
    const VKDetectorConstruction* fDetConstr;
    VKMaterials* fMaterials;
    
    // Dimensions
    G4double fCoilInnerDiameter;
    G4double fCoilOuterDiameter;
    G4double fCoilWidth;
    G4double fCoilSeparation;    
    G4double fIronBarrelInnerDiameter;
    G4double fIronBarrelThickness;
    G4double fIronEndcapThickness;
    G4double fIronEndcapHoleDiameter; 
    G4double fIronConeInnerDiameter; 
    G4double fIronConeOuterDiameterMin;
    G4double fIronConeOuterDiameterMax;
    G4double fIronConeLength;
    G4double fSpectrometerLength;
    G4double fBrassInnerDiameter;
    G4double fBrassThickness;
    G4double fBrassLength;
    G4double fContainerDiameter;
    G4double fContainerLength;
            
    // Geometry
    bool fCheckOverlaps;
    G4LogicalVolume* fMother_log;    
    G4Tubs* fContainer_sol;
    G4LogicalVolume* fContainer_log;

    G4UnionSolid* fCoils_sol;
    G4LogicalVolume* fCoils_log;    
    
    G4UnionSolid* fIronWalls_sol;
    G4LogicalVolume* fIronWalls_log; 
    
    G4Tubs* fBrassWalls_sol;
    G4LogicalVolume* fBrassWalls_log;   

//*** G4Tubs* extra_sol;
//*** G4LogicalVolume* extra_log;   
};

#endif
